@@ -1,5 +1,5 @@
 package YAML;
-our $VERSION = '1.28';
+our $VERSION = '1.31';
 
 use YAML::Mo;
 
@@ -13,12 +13,10 @@ our (
     $UseHeader, $UseVersion, $UseBlock, $UseFold, $UseAliases,
     $Indent, $SortKeys, $Preserve,
     $AnchorPrefix, $CompressSeries, $InlineSeries, $Purity,
-    $Stringify, $Numify, $LoadBlessed,
+    $Stringify, $Numify, $LoadBlessed, $QuoteNumericStrings,
+    $DumperClass, $LoaderClass
 );
 
-$LoadBlessed = 1;
-
-
 use YAML::Node; # XXX This is a temp fix for Module::Build
 use Scalar::Util qw/ openhandle /;
 
